@@ -161,7 +161,7 @@ class CallbackContainer:
         output_margin: bool = True,
         is_cv: bool = False,
     ) -> None:
-        self.callbacks = set(callbacks)
+        self.callbacks = list(dict.fromkeys(callbacks))
         for cb in callbacks:
             if not isinstance(cb, TrainingCallback):
                 raise TypeError("callback must be an instance of `TrainingCallback`.")
